==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS","ҦsDDD");
define("_NOCOMMENTS","ܷN");

define("_UCOMMENT","");
define("_REVIEWS","@~");
define("_SEARCHUSERS","jMϥΪ̸Ʈw");
define("_SEARCHSECTIONS","jMM");
define("_SEARCHREVIEWS","jM@~N");
define("_SEARCHIN","jMb");
define("_ARTICLES","峹");
define("_ALLAUTHORS","@");
define("_ALL","");
define("_WEEK","P");
define("_WEEKS","P");
define("_MONTH","");
define("_MONTHS","");
define("_SEARCHON","jMG");
define("_SSTORIES","");
define("_SSECTIONS","M");
define("_SUSERS","ϥΪ");
define("_NOMATCHES","䤣Pz߰ݱ۲Ū");
define("_PREVMATCHES","e@");
define("_NEXTMATCHES","U@");
define("_INSECTION","M椺峹");
define("_NONAME","W٩|J");
define("_SCOMMENTS","");
define("_SEARCHRESULTS","jMG");
define("_CONTRIBUTEDBY","Ѫ̬");
define("_UCOMMENTS","N");
define("_MATCHTITLE","MDkX");
define("_MATCHTEXT","M峹ekX");
define("_MATCHBOTH","MDP峹ekX");
define("_SREPLY","^");
define("_SREPLIES","^");
define("_ATTACHART","峹");
define("_PAGES","");
define("_REVIEWSCORE","@~׵");
define("_PAGE","");



?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_ALLTOPICS","ҦsDDD");
define("_NOCOMMENTS","ܷN");

define("_UCOMMENT","");
define("_REVIEWS","@~");
define("_SEARCHUSERS","jMϥΪ̸Ʈw");
define("_SEARCHSECTIONS","jMM");
define("_SEARCHREVIEWS","jM@~N");
define("_SEARCHIN","jMb");
define("_ARTICLES","峹");
define("_ALLAUTHORS","@");
define("_ALL","");
define("_WEEK","P");
define("_WEEKS","P");
define("_MONTH","");
define("_MONTHS","");
define("_SEARCHON","jMG");
define("_SSTORIES","");
define("_SSECTIONS","M");
define("_SUSERS","ϥΪ");
define("_NOMATCHES","䤣Pz߰ݱ۲Ū");
define("_PREVMATCHES","e@");
define("_NEXTMATCHES","U@");
define("_INSECTION","M椺峹");
define("_NONAME","W٩|J");
define("_SCOMMENTS","");
define("_SEARCHRESULTS","jMG");
define("_CONTRIBUTEDBY","Ѫ̬");
define("_UCOMMENTS","N");
define("_MATCHTITLE","MDkX");
define("_MATCHTEXT","M峹ekX");
define("_MATCHBOTH","MDP峹ekX");
define("_SREPLY","^");
define("_SREPLIES","^");
define("_ATTACHART","峹");
define("_PAGES","");
define("_REVIEWSCORE","@~׵");
define("_PAGE","");



?>
